"use strict";
exports.__esModule = true;
exports.toRollup = void 0;
var compose_1 = require("../../utils/compose");
var strings_1 = require("../../utils/strings");
var createCustomResolver_1 = require("./createCustomResolver");
var getFallbackAlias_1 = require("./getFallbackAlias");
function toPluginAliasFormat(config) {
    return Object.entries(config).map(function (_a) {
        var moduleName = _a[0], modulePath = _a[1];
        var replacement = Array.isArray(modulePath) ? moduleName : modulePath;
        return {
            find: moduleName,
            replacement: replacement
        };
    });
}
function normalizeWildcards(declarations) {
    return declarations.map(function (declaration) {
        var find = declaration.find, replacement = declaration.replacement;
        if (typeof find === 'string' && find.includes('*')) {
            var transformedModuleName = strings_1.normalizeWildcardString(find);
            var moduleNameRegExp = new RegExp(transformedModuleName);
            var transformedReplacement = typeof replacement === 'function'
                ? replacement
                : strings_1.replaceWildcardWithPositionals(replacement);
            return {
                find: moduleNameRegExp,
                replacement: transformedReplacement
            };
        }
        return declaration;
    });
}
/**
 * Generates the configuration for the `@rollup/plugin-alias` plugin
 * with the given path alias.
 */
function toRollup(config) {
    var entries = compose_1.compose(normalizeWildcards, toPluginAliasFormat)(config);
    var fallbackAlias = getFallbackAlias_1.getFallbackAlias(config);
    return Object.assign({}, {
        entries: entries
    }, fallbackAlias.length > 0 && {
        customResolver: createCustomResolver_1.createCustomResolver(fallbackAlias)
    });
}
exports.toRollup = toRollup;
